package com.anabas.eventbus;

/**
 * Title:
 * Description:
 * Copyright:    Copyright (c) 2000
 * Company:
 * @author
 * @version 1.0
 *
 * Application creatable message types.  Some internal messages such as
 * clock, network, ... message types are not available to the application
 * developer.
 */

public abstract class Message implements Externalizable {

  public final static short MSGTYPE_ADMINISTRATION = 0;
  public final static short MSGTYPE_MINOR          = 1;
  public final static short MSGTYPE_MAJOR          = 2;
  public final static short MSGTYPE_ACK            = 3;

  // ????
  public final static short BODYTYPE_STREAM        = 0;
  public final static short BODYTYPE_TEXT          = 1;
  public final static short BODYTYPE_MAP           = 2;
  public final static short BODYTYPE_OBJECT        = 3;
  public final static short BODYTYPE_BYTES         = 4;
  public final static short BODYTYPE_XML           = 5;

  public final static short PRIORITY_REALTIME   = 100;
  public final static short PRIORITY_NORMAL     = 50;
  public final static short PRIORITY_LOW        = 0;

  /**
   * @return One of the types defined as BODYTYPE_XXX
   */
  public abstract short       getBodyType();

  /**
   * Message property definition.
   */
  public abstract Object      getProperty(String name);

  public abstract void        setProperty(String name,Object property) throws ReadOnlyException;

  /* ====================== Header Field ========================== */

  /**
   * @return The time stamp of when the message was sent within the global time
   *         system.
   */
  public abstract Time  getTimeStamp();

  /**
   * Uniquely identifies it from other messages within the system.
   *
   * ?? Should it be unique within the system?
   */
  public abstract MessageID   getID();

  /**
   * @return The priority of the message
   */
  public abstract short       getPriority();

  /**
   * One of ADMINSTRATION, NORMAL, or ACK.
   */
  public abstract short       getMessageType();

}

