package com.anabas.eventbus;

import javax.naming.directory.*;

/**
 * Title:
 * Description:
 * Copyright:    Copyright (c) 2000
 * Company:
 * @author
 * @version 1.0
 *
 * Implements externalizable so that it can be stored and reconstructed later.
 * Good for PDA, ...
 *
 * A stream context and all stream contexts & streams below it should be destroyed
 * by the provider as soon as it is disconnected from the root context.
 */

public interface StreamContext extends DirContext implements Externalizable {

  public void removeContextListener(StreamContextListener l);
  public void addContextListener(StreamContextListener l) throw IllegalAccessException;

  /**
   * Convenience function for DirContext.search()
   *
   * @return A destination object that matches the destination selector.
   *         null if no matches.
   */
  public Destination   findDestination(DestinationSelector d) throws IllegalAccessException;


  /**
   * Finds a stream within this context by the name specified.
   *
   * Name is relative to within this context.
   */
  public Stream        findStream(String name) throws NotStreamException;

  /**
   * Find a subcontext of this stream.
   */
  public StreamContext findStreamContext(String name) throws NotContextException;

  /**
   * Convenience function for DirContext.createSubcontext();
   *
   * Creates a new sub context within the larger stream context.  Each context
   * can contain other sub contexts or streams (leaf nodes)
   */
  public StreamContext createSubcontext(String name) throws IllegalAccessException;


  /**
   * Binds another stream context or stream under this context.  Or potentially
   * other types of objects.
   */
  public void bind(String name,Object obj);

  /**
   * Creates a new stream within the stream context.  A stream is the leaf node
   * of a stream tree.  Basically a DirContext.bind(name,StreamContext) operation.
   *
   * @param params A list of parameters for the stream.  For example:
   *        "min_latency" - "50ms"
   *        "encrypted"   - "true"
   *        "persistent"  - "none"
   */
  public Stream        createStream(String name,Hashtable params) throws IllegalAccessException;
}


